@@ -1,3 +1,11 @@
+# 
+# This file is part of Padre-Plugin-Plack
+# 
+# This software is copyright (c) 2010 by Patrick Donelan.
+# 
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+# 
 package Padre::Plugin::Plack::Panel;
 
 use strict;
@@ -50,6 +58,7 @@ sub gettext_label {
 
 # dirty hack to allow seamless use of Padre::Wx::Output
 sub bottom { return $_[0] }
+sub main { warn "here"; return Padre::Current->main }
 
 # taken from Padre::Plugin::Catalyst
 sub led {
@@ -291,3 +300,28 @@ sub led {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Padre::Plugin::Plack::Panel
+
+=head1 VERSION
+
+version 0.100970
+
+=head1 AUTHOR
+
+  Patrick Donelan <pat@patspam.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Patrick Donelan.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
